import os
os.environ["FIX_TORCH_ERROR"] = "0"

import jittor as jt
import jtorch
from jtorch import *
__version__ = "2.0.0"

import sys
def load_mod(name):
    exec("import "+name)
    return eval(name)

autograd = sys.modules["torch.autograd"] = load_mod("jtorch.autograd")
sys.modules["torch.cuda"] = load_mod("jtorch.cuda")
sys.modules["torch.nn"] = load_mod("jtorch.nn")
sys.modules["torch.nn.functional"] = load_mod("jtorch.nn")
sys.modules["torch.nn.modules"] = load_mod("jtorch.nn")
jtorch.nn.module = jtorch.nn
sys.modules["torch.nn.parameter"] = load_mod("jtorch.nn")
jtorch.nn.parameter = jtorch.nn
sys.modules["torch.nn.utils"] = load_mod("jtorch.nn")
jtorch.nn.functional = jtorch.nn
sys.modules["torch.utils"] = load_mod("jtorch.utils")
sys.modules["torch._utils"] = load_mod("jtorch.utils")
sys.modules["torch.utils.data"] = load_mod("jtorch.utils.data")
sys.modules["torch.utils.data.sampler"] = load_mod("jtorch.utils.data")
jtorch.utils.data.sampler = jtorch.utils.data
sys.modules["torch.utils.checkpoint"] = load_mod("jtorch.utils.checkpoint")

distributed = sys.modules["torch.distributed"] = load_mod("jtorch.distributed")
sys.modules["torch.nn.parallel"] = load_mod("jtorch.distributed")
sys.modules["torch.nn.parallel.distributed"] = load_mod("jtorch.distributed")
_C = sys.modules["torch._C"] = load_mod("jtorch.misc")
_six = sys.modules["torch._six"] = load_mod("jtorch.misc")
jit = sys.modules["torch.jit"] = load_mod("jtorch.misc")

sys.modules["torchvision"] = load_mod("jtorch.vision")
sys.modules["torchvision.datasets"] = load_mod("jtorch.vision.datasets")
sys.modules["torchvision.transforms"] = load_mod("jtorch.vision.transforms")
sys.modules["torchvision.transforms.functional"] = load_mod("jtorch.vision.transforms")
jtorch.vision.transforms.functional = jtorch.vision.transforms



import math

def _jit_set_profiling_mode(x): pass
def _jit_set_profiling_executor(x): pass
def _jit_override_can_fuse_on_cpu(x): pass
def _jit_override_can_fuse_on_gpu(x): pass

def script(func):
    return func

inf = math.inf
nan = math.nan


import jittor as jt
import jtorch

def is_available():
    return jt.has_cuda

def device_count():
    return int(jt.has_cuda)

def set_device(device=None):
    pass

def get_rng_state(device=None):
    pass

def current_device():
    return jtorch.device("cuda")

class Generator:
    def __init__(self):
        pass

    def set_state(self, state):
        self.state = state

default_generators = [Generator()]
_lazy_call = lambda func: func()
device = None

LongTensor = jt.int64
FloatTensor = jt.float
HalfTensor = jt.float16
BoolTensor = jt.bool

manual_seed = jt.set_global_seed

def synchronize():
    jt.sync_all(True)



import datetime
from enum import Enum


class DistributedDataParallel:
    def __new__(cls, model):
        return model

def is_initialized():
    return True

def get_rank(group=None):
    return 0

def get_world_size(group=None):
    return 1

def get_backend(group=None):
    return "nccl"

def new_group(ranks=None, timeout=datetime.timedelta(seconds=1800), backend=None, pg_options=None):
    return 1

def barrier():
    pass

dist_backend = Enum("dist_backend", ("GLOO", "MPI", "NCCL"))
_backend = dist_backend.NCCL